import { FontObjectV1, FontObjectV2, FontObjectVariable } from 'google-font-metadata';

interface CLIOptions {
    test?: boolean;
    force?: boolean;
    ttf?: boolean;
}
interface BuildOptions {
    dir: string;
    tmpDir: string;
    force: boolean;
    isVariable: boolean;
    noSubset?: boolean;
    isIcon?: boolean;
    version?: string;
    publishHash?: string;
    ttf?: boolean;
}
interface CSSGenerateItem {
    filename: string;
    css: string;
}
type CSSGenerate = CSSGenerateItem[];

/**
 * We need to generate all CSS in this one file to ensure that pkgroll
 * exports these functions without accidentally importing unnecessary
 * node modules. Unfortunately mixing other functions leads to node
 * imports breaking builds that don't run in Node environments.
 */
type GenerateMetadataV1 = Pick<FontObjectV1['id'], 'id' | 'family' | 'styles' | 'weights' | 'subsets' | 'variants'>;
type GenerateMetadataV2 = Pick<FontObjectV2['id'], 'id' | 'family' | 'styles' | 'weights' | 'subsets' | 'variants' | 'unicodeRange'>;
type GenerateMetadataVariable = Pick<FontObjectVariable['id'], 'axes' | 'variants'>;
type GenerateIconStatic = Pick<FontObjectV2['id'], 'id' | 'family' | 'styles' | 'weights' | 'subsets' | 'variants'>;
type GenerateIconVariable = Pick<FontObjectVariable['id'], 'id' | 'family' | 'axes' | 'variants'>;
declare const generateV1CSS: (metadata: GenerateMetadataV1, makeFontFilePath: (id: string, subset: string, weight: string, style: string, extension: string) => string, tag?: string) => CSSGenerate;
declare const generateV2CSS: (metadata: GenerateMetadataV2, makeFontFilePath: (id: string, subset: string, weight: string, style: string, extension: string) => string, tag?: string) => CSSGenerate;
declare const generateVariableCSS: (metadata: GenerateMetadataV2, variableMeta: GenerateMetadataVariable, makeFontFilePath: (id: string, subset: string, axes: string, style: string) => string, tag?: string) => CSSGenerate;
declare const generateIconStaticCSS: (metadata: GenerateIconStatic, makeFontFilePath: (id: string, subset: string, weight: string, style: string, extension: string) => string, tag?: string) => CSSGenerate;
declare const generateIconVariableCSS: (metadata: GenerateIconVariable, makeFontFilePath: (id: string, subset: string, axesLower: string, style: string) => string, tag?: string) => CSSGenerate;

export { BuildOptions as B, CLIOptions as C, generateIconVariableCSS as a, generateV1CSS as b, generateV2CSS as c, generateVariableCSS as d, generateIconStaticCSS as g };
